<id>
BoardSort
</id>

<version>
2.0rc1
</version>

<mod info>
This mod adds the ability to sort the board (message) index in ascending or descending order by clicking on the 5 column headings. In addition, the admin can set a default sort order on a per-board basis. The user's sort preference is saved in a cookie on a per-board basis. This mod was inspired by "Message_Sort_SP11.mod" by BHRA Webmaster.

BoardSort 2.0 is NOT compatible with the nice "StickyGroup.mod" by DummyProof, but the functionality of that mod IS included in BoardSort. If you have StickyGroup.mod installed, uninstall it first. (For those that don't know, StickyGroup.mod simply adds divider bars between the "sticky" and "normal" threads, like as seen on the http://www.boardmod.org forums.) 

BoardSort 2.0 is also NOT compatible with with mods like "topic rating" or "moderation update" that add extra columns to the message index. You will need to tweak this mod if you are actively using such mods.

The sorting code is optimized to be extremely efficient. If you are familiar with perl, have a look at the SortTopics() subroutine. I welcome any feedback on further optimizations.

Also of note: the "Prev Thread" and "Next Thread" links (present when reading a topic) are now "sticky-aware", which they were not previously! :-)

The code for determining which threads are sticky was also re-written for efficiency, while still maintaining compatability.

Sticky threads are NOT affected by sorting selections but remain displayed in "most recently sticky'd" order, just as before. If you want to be able to quickly re-order your sticky topics, check out the very cool "Sticky_Shimmy_Shuffle_beta_1b.mod" by astropilot here: http://www.boardmod.org/yabb/YaBB.pl?board=new_mods_beta;action=display;num=1088179082

The admin can choose from the following default sort orders for each board:
  Normal (no sorting - the default YaBB order)
  Last post (oldest first)
  Last post (newest first)
  Subject (alphabetical)
  Subject (reverse alphabetical)
  Topic creator (alphabetical)
  Topic creator (reverse alphabetical)
  Replies (least to most)
  Replies (most to least)
  Views (least to most)
  Views (most to least)

Note that "Last post (newest first)" can be different than the "Normal" option, especially when threads are moved between boards, topics are split/spliced, etc. and old threads get "pushed" to the top of list. Also, it is worth noting that sorting by "Views" and then using the previous/next links to navigate is somewhat unpredictable: every time you view a thread, the number of Views goes up by one, potentially changing the sort order with every click. Similarly, if you are sorting by "Replies" and reply to a thread, the previous/next links may also have changed because of the new reply.

Install this mod using BoardMod and upload these 5 files that are modified:
  Sources/Subs.pl
  Sources/MessageIndex.pl
  Sources/Display.pl
  Sources/ManageBoards.pl
  english.lng

Finally, go into the "BoardSort Images" folder and pick an appropriate color for the sort icons (or modify as desired). Transfer "sortasc.gif", "sortdesc.gif" and "unsort.gif" to your YaBBImages directory.

Tested on YaBB 1 Gold - SP 1.3.1, but also applies cleanly on SP 1.4 (although not tested).
</mod info>

<author>
Eddy
</author>

<homepage>
http://www.boardmod.org
</homepage>

<edit file>
Sources/Subs.pl
</edit file>

<search for>

1;
</search for>

<add before>

use Time::Local;

sub _extractDate
{
    my ($m,$d,$y,$h,$mn,$s) = ((split /\|/, $_, 9)[4] =~ m~(\d+)/(\d+)/(\d+) at (\d+):(\d+):(\d+)~);
    return timelocal($s, $mn, $h, $d, $m - 1, $y);
}

sub _extractViews
{
    my $data, $mnum = (split /\|/, $_, 9)[0];
    fopen(FILE, "$datadir/$mnum.data") || &fatal_error("300 $txt{'106'}: $txt{'23'} $datadir/$mnum.data");
    $data = <FILE>;
    fclose(FILE);
    return $data;
}

sub SortTopics
{
    # Note: this subroutine expects to be passed a reference to a threadlist
    my $threadlist = shift;
    my @sortlist;

    # preallocate the cache hashes to improve performance
    keys my %cache1 = @$threadlist;
    keys my %cache2 = @$threadlist;

    # efficiently populate the caches based on desired sort order
    if ($sort_order eq "subject") {
	($cache1{$_}, $cache2{$_}) = map { uc((split /\|/, $_, 9)[1]), _extractDate($_) } $_ for @$threadlist;
    } elsif ($sort_order eq "creator") {
	($cache1{$_}, $cache2{$_}) = map { uc((split /\|/, $_, 9)[2]), _extractDate($_) } $_ for @$threadlist;
    } elsif ($sort_order eq "latest") {
	($cache1{$_}, $cache2{$_}) = map { _extractDate($_), 0 } $_ for @$threadlist;
    } elsif ($sort_order eq "replies") {
	($cache1{$_}, $cache2{$_}) = map { (split /\|/, $_, 9)[5], _extractDate($_) } $_ for @$threadlist;
    } elsif ($sort_order eq "views") {
	($cache1{$_}, $cache2{$_}) = map { _extractViews($_), _extractDate($_) } $_ for @$threadlist;
    }

    # now actually do the sort, as either an alpha sort or a numeric sort, using "last post date" (most recent first) as tie-breaker
    if ($sort_order eq "subject" || $sort_order eq "creator") {
	# Note: we compare the subject using the numeric comparison operator first so that threads that start with a number
	# appear in proper numeric order (i.e., 1, 2, 10 instead of 1, 10, 2), and after the threads that start with alphabetic chars
	# Alphabetic sorts default to ascending if $sort_dir isn't specified
	if ($sort_dir eq "desc") {
	    @sortlist = sort { $cache1{$b} <=> $cache1{$a} || $cache1{$b} cmp $cache1{$a} || $cache2{$b} <=> $cache2{$a} } @$threadlist;
	} else {
	    $sort_dir = "asc";
	    @sortlist = sort { $cache1{$a} <=> $cache1{$b} || $cache1{$a} cmp $cache1{$b} || $cache2{$b} <=> $cache2{$a} } @$threadlist;
	}
    } else {
	# Numeric sorts default to descending if $sort_dir isn't specified
	if ($sort_dir eq "asc") {
	    @sortlist = sort { $cache1{$a} <=> $cache1{$b} || $cache2{$b} <=> $cache2{$a} } @$threadlist;
	} else {
	    $sort_dir = "desc";
	    @sortlist = sort { $cache1{$b} <=> $cache1{$a} || $cache2{$b} <=> $cache2{$a} } @$threadlist;
	}
    }

    return @sortlist;
}
</add before>

<edit file>
Sources/MessageIndex.pl
</edit file>

<search for>
	# Construct the page links for this board.
</search for>

<add before>
	# Open and quickly read the current board thread list.
	# Skip past threads until we reach the "page" we want.
	fopen(FILE, "$boardsdir/$currentboard.txt") || &fatal_error("300 $txt{'106'}: $txt{'23'} $currentboard.txt");
	@threadlist = <FILE>;
	$threadcount = $#threadlist;
	@threadlist2 = '';
	fclose(FILE);

	# Determine sort order
	$default_sort = "-";
	if (-e "$boardsdir/$currentboard.ord" ) { require "$boardsdir/$currentboard.ord"; }

	# Use 'sort' option in URL as primary sort order, then sort order cookie, then $default_sort
	($sort_order,$sort_dir) = split('-', $INFO{'sort'} || $yyCookies{"YaBBorder.$currentboard"} || $default_sort);
	$sort_order = "" if ($sort_order ne "subject" && $sort_order ne "creator" && $sort_order ne "latest" && $sort_order ne "replies" && $sort_order ne "views");
	$sort_dir = "" if (!defined($sort_dir) || ($sort_dir ne "asc" && $sort_dir ne "desc"));

	# Set or remove the "order" cookie
	if ($default_sort eq "$sort_order-$sort_dir") {
	    # If the sort order is set to the board default, delete the sort order cookie
	    $yySetCookies1 = cookie(-name => "YaBBorder.$currentboard", -expires => "Thu, 01-Jan-1970 00:00:00 GMT");
	} elsif (($INFO{'sort'} && $yyCookies{"YaBBorder.$currentboard"} ne "$sort_order-$sort_dir" && $sort_order ne "") || ($default_sort ne "-" && $sort_order eq "")) {
	    # If the user clicked on a column heading (causing ';sort' to be added to the URL) and the sort option is not the same as the existing cookie, set a cookie
            $yySetCookies1 = cookie(-name => "YaBBorder.$currentboard", -value => "$sort_order-$sort_dir", -expires => "Mon, 31-Dec-2035 23:59:59 GMT"); 
	}

	# Sort threads
	if ($sort_order ne "" && $threadcount > 0) {
	    @threadlist = SortTopics(\@threadlist);
	}

</add before>

<search for>
	# Open and quickly read the current board thread list.
	# Skip past threads until we reach the "page" we want.
	fopen(FILE, "$boardsdir/$currentboard.txt") || &fatal_error("300 $txt{'106'}: $txt{'23'} $currentboard.txt");
	@threadlist = <FILE>;
	$threadcount = $#threadlist;
	@threadlist2 = '';
	fclose(FILE);

	# Sticky Threads
	fopen(FILE, "$boardsdir/sticky.stk") || &fatal_error("300 $txt{'106'}: $txt{'23'} sticky.stk");
	@stickys = <FILE>;
	$stickycount = $#stickys;
	fclose(FILE);
	for ($i=0; $i<=$threadcount; $i++) {
		($mnum) = split( /\|/, $threadlist[$i] );
		$l = 0;
		$is = 0;
		foreach $curnum (@stickys) {
			if ($mnum == $curnum) {
				$is = 1;
				$stickylist{$l} = $threadlist[$i];
				#splice(@threadlist,$i,1);
				last;
			}
			$l++;
		}
		if ($is == 0) { push(@threadlist2,$threadlist[$i]); }
	}
	if (!($threadlist2[0])) { shift(@threadlist2); }

	#now sort the stickys
	@stickylist2 = sort {$b <=> $a } keys %stickylist;
	for ($i=0; $i<=$stickycount; $i++) {
		chomp $stickylist{$i};
		if ($stickylist{$i}) { unshift(@threadlist2,"$stickylist{$i}\n"); }
	}
</search for>

<replace>
	# Sticky Threads
	my %stickyhash = %stickyorder = @normallist = ();
	my $stickycount = 0;
	fopen(FILE, "$boardsdir/sticky.stk") || &fatal_error("300 $txt{'106'}: $txt{'23'} sticky.stk");
	while (<FILE>) {
	    chomp;
	    $stickyhash{$_} = $stickycount++;
	}
	fclose(FILE);

	$stickycount = 0;
	foreach $thread (@threadlist) {
	    ($mnum) = split(/\|/, $thread);
	    if (defined($stickyhash{$mnum})) {
		$stickyorder{$stickyhash{$mnum}} = $thread;
		$stickycount++;
	    } else {
		push(@normallist, $thread);
	    }
	}
	@threadlist2 = (map($stickyorder{$_}, sort { $b <=> $a } keys %stickyorder), @normallist);
	$stickynum = $start < $maxdisplay ? $stickycount : 0;
</replace>

<search for>
	# Begin printing the message index for current board.
</search for>

<add after>
	if ($stickynum) {
	    $yymain .= qq~
      <tr>
	<td colspan="7" align="left" class="catbg" bgcolor="$color{'catbg'}" width="100%"><font size="1">&nbsp;$board_sort{'sticky'}</font></td>
      </tr>
~;
	}
</add after>
	
<search for>
		foreach $curnum (@stickys) {
			if ($mnum == $curnum) {
				if($threadclass eq 'locked') { $threadclass = 'stickylock'; }
				else { $threadclass = 'sticky'; }
			}
		}
</search for>

<replace>
		$threadclass = $threadclass eq 'locked' ? 'stickylock' : 'sticky' if defined($stickyhash{$mnum});
</replace>

<search for>
		# Print the thread info.
</search for>

<add after>
		if ($stickynum && $counter >= $stickynum && !$normalshown) {
		    $yymain .= qq~
      <tr>
        <td colspan="7" align="left" class="catbg" bgcolor="$color{'catbg'}" width="100%"><font size="1">&nbsp;$board_sort{'normal'}</font></td>
      </tr>
~;
		    $normalshown = 1;
		}
</add after>

<search for>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="10%" colspan="2"><font size="2">&nbsp;</font></td>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="44%"><font size="2" class="text1" color="$color{'titletext'}"><b>$txt{'70'}</b></font></td>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="14%" align="center"><font size="2" class="text1" color="$color{'titletext'}"><b>$txt{'109'}</b></font></td>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="4%" align="center"><font size="2" class="text1" color="$color{'titletext'}"><b>$txt{'110'}</b></font></td>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="4%" align="center"><font size="2" class="text1" color="$color{'titletext'}"><b>$txt{'301'}</b></font></td>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="24%"><font size="2" class="text1" color="$color{'titletext'}"><b>$txt{'111'}</b></font></td>
</search for>

<replace>
        <td class="titlebg" bgcolor="$color{'titlebg'}" width="10%" colspan="2"><font size="2">~;
	my $url = qq~$cgi;action=messageindex;start=$start;sort=~;
	if ($sort_order ne "") {
	    $yymain .= qq~<a href="${url}normal" title="$board_sort{'unsort2'}">$img{'remove-sort'}</a>~;
	} else {
	    $yymain .= qq~&nbsp;~;
	}
	$yymain .= qq~</font></td>\n<td class="titlebg" bgcolor="$color{'titlebg'}" width="44%"><font size="2" class="text1" style="font-weight: normal" color="$color{'titletext'}">~;
	if ($sort_order eq "subject") {
	    my $url2 = $sort_dir eq "asc" ? qq~subject-desc" title="$board_sort{'subject-desc'}~ : qq~subject-asc" title="$board_sort{'subject-asc'}~;
	    $yymain .= qq~<a href="$url$url2"><b>$txt{'70'}</b> $img{"sort-$sort_dir"}</a>~;
	} else {
	    $yymain .= qq~<a href="${url}subject-asc" title="$board_sort{'subject-asc'}">$txt{'70'}</a>~;
	}
	$yymain .= qq~</font></td>\n<td class="titlebg" bgcolor="$color{'titlebg'}" width="14%" align="center"><font size="2" class="text1" style="font-weight: normal" color="$color{'titletext'}">~;
	if ($sort_order eq "creator") {
	    my $url2 = $sort_dir eq "asc" ? qq~creator-desc" title="$board_sort{'creator-desc'}~ : qq~creator-asc" title="$board_sort{'creator-asc'}~;
	    $yymain .= qq~<a href="$url$url2"><b>$txt{'109'}</b> $img{"sort-$sort_dir"}</a>~;
	} else {
	    $yymain .= qq~<a href="${url}creator-asc" title="$board_sort{'creator-asc'}">$txt{'109'}</a>~;
	}
	$yymain .= qq~</font></td>\n<td class="titlebg" bgcolor="$color{'titlebg'}" width="4%" align="center"><font size="2" class="text1" style="font-weight: normal" color="$color{'titletext'}">~;
	if ($sort_order eq "replies") {
	    my $url2 = $sort_dir eq "asc" ? qq~replies-desc" title="$board_sort{'replies-desc'}~ : qq~replies-asc" title="$board_sort{'replies-asc'}~;
	    $yymain .= qq~<a href="$url$url2"><b>$txt{'110'}</b> $img{"sort-$sort_dir"}</a>~;
	} else {
	    $yymain .= qq~<a href="${url}replies-desc" title="$board_sort{'replies-desc'}">$txt{'110'}</a>~;
	}
	$yymain .= qq~</font></td>\n<td class="titlebg" bgcolor="$color{'titlebg'}" width="4%" align="center"><font size="2" class="text1" style="font-weight: normal" color="$color{'titletext'}">~;
	if ($sort_order eq "views") {
	    my $url2 = $sort_dir eq "asc" ? qq~views-desc" title="$board_sort{'views-desc'}~ : qq~views-asc" title="$board_sort{'views-asc'}~;
	    $yymain .= qq~<a href="$url$url2"><b>$txt{'301'}</b> $img{"sort-$sort_dir"}</a>~;
	} else {
	    $yymain .= qq~<a href="${url}views-desc" title="$board_sort{'views-desc'}">$txt{'301'}</a>~;
	}
	$yymain .= qq~</font></td>\n<td class="titlebg" bgcolor="$color{'titlebg'}" width="24%"><font size="2" class="text1" style="font-weight: normal" color="$color{'titletext'}">~;
	if ($sort_order eq "latest") {
	    my $url2 = $sort_dir eq "asc" ? qq~latest-desc" title="$board_sort{'latest-desc'}~ : qq~latest-asc" title="$board_sort{'latest-asc'}~;
	    $yymain .= qq~<a href="$url$url2"><b>$txt{'111'}</b> $img{"sort-$sort_dir"}</a>~;
	} else {
	    $yymain .= qq~<a href="${url}latest-desc" title="$board_sort{'latest-desc'}">$txt{'111'}</a>~;
	}
	$yymain .= qq~</font></td>
</replace>

<edit file>
Sources/Display.pl
</edit file>

<search for>
	fopen(LISTS, "$boardsdir/$INFO{'board'}.txt");
	@boardtopics = <LISTS>;
	seek LISTS, 0, 0;
	my $found;
	my $name = $INFO{'num'};
	my $bcount = 0;
	$CurrentPosition = -1;
	while($ThreadNum = <LISTS>) {
		++$CurrentPosition;
		$boardtopics[$bcount] = $ThreadNum;
		$bcount++;
		if ($ThreadNum =~ m/\A$name/o) { $found = 1; last; }
	}
	fclose(LISTS);
</search for>

<replace>
	fopen(LISTS, "$boardsdir/$INFO{'board'}.txt");
	@boardtopics = <LISTS>;
	fclose(LISTS);

	# Determine sort order
	$default_sort = "";
	if (-e "$boardsdir/$currentboard.ord" ) { require "$boardsdir/$currentboard.ord"; }

	# Look for sort order cookie, then $default_sort
	($sort_order,$sort_dir) = split('-', $yyCookies{"YaBBorder.$currentboard"} || $default_sort);
	$sort_order = "" if ($sort_order ne "subject" && $sort_order ne "creator" && $sort_order ne "latest" && $sort_order ne "replies" && $sort_order ne "views");
	$sort_dir = "" if (!defined($sort_dir) || ($sort_dir ne "asc" && $sort_dir ne "desc"));

	# Sort threads
	if ($sort_order ne "") {
	    @boardtopics = SortTopics(\@boardtopics);
	}

	# Now compensate for sticky threads... (this functionality is new; the prev/next links used to just ignore sticky threads being "first")
	my %stickyhash = %stickyorder = @normallist = ();
	my $stickycount = 0;
	fopen(FILE, "$boardsdir/sticky.stk") || &fatal_error("300 $txt{'106'}: $txt{'23'} sticky.stk");
	while (<FILE>) {
	    chomp;
	    $stickyhash{$_} = $stickycount++;
	}
	fclose(FILE);

	foreach $thread (@boardtopics) {
	    ($mnum) = split(/\|/, $thread);
	    if (defined($stickyhash{$mnum})) {
		$stickyorder{$stickyhash{$mnum}} = $thread;
	    } else {
		push(@normallist, $thread);
	    }
	}
	@boardtopics = (map($stickyorder{$_}, sort { $b <=> $a } keys %stickyorder), @normallist);

	my $found;
	my $name = $INFO{'num'};
	my $bcount = 0;
	$CurrentPosition = -1;
	foreach $ThreadNum (@boardtopics) {
		++$CurrentPosition;
		if ($ThreadNum =~ m/\A$name/o) { $found = 1; last; }
	}
</replace>

<edit file>
Sources/ManageBoards.pl
</edit file>

<search for>
				$multimoderators = $1 or $multimoderators = $boardinfo[2];
				$multimoderators =~ s/\|(\S?)/,$1/g;
</search for>

<add after>
				
				my %currsort = ();
				if ( -e("$boardsdir/$curboard.ord") ) {
				    require "$boardsdir/$curboard.ord";
				    $currsort{$default_sort} = " selected";
				} else {
				    $currsort{'-'} = " selected";
				}
</add after>

<search for>
        <input type="submit" name="moda" value="$txt{'31'}"></td>
      </tr>
</search for>

<add after>
      <tr>
        <td></td>
	<td colspan="3">
	  <font size="2"><b>$board_sort{'menu-title'}:</b></font>&nbsp; 
          <select name="default_sort" size=1>
            <option value="-"$currsort{'-'}>$board_sort{'normal-opt'}
            <option value="latest-asc"$currsort{'latest-asc'}>$board_sort{'latest-asc-opt'}
            <option value="latest-desc"$currsort{'latest-desc'}>$board_sort{'latest-desc-opt'}
            <option value="subject-asc"$currsort{'subject-asc'}>$board_sort{'subj-asc-opt'}
            <option value="subject-desc"$currsort{'subject-desc'}>$board_sort{'subj-desc-opt'}
            <option value="creator-asc"$currsort{'creator-asc'}>$board_sort{'creat-asc-opt'}
            <option value="creator-desc"$currsort{'creator-desc'}>$board_sort{'creat-desc-opt'}
            <option value="replies-asc"$currsort{'replies-asc'}>$board_sort{'repl-asc-opt'}
            <option value="replies-desc"$currsort{'replies-desc'}>$board_sort{'repl-desc-opt'}
            <option value="views-asc"$currsort{'views-asc'}>$board_sort{'views-asc-opt'}
            <option value="views-desc"$currsort{'views-desc'}>$board_sort{'views-desc-opt'}
          </select>
        </td>
      </tr>
</add after>

<search for>
        <td valign="bottom" width="20%"><input type=submit value="$txt{'45'}"></td>
      </tr>
</search for>

<add after>
      <tr>
        <td colspan="3">
	  <font size="2"><b>$board_sort{'menu-title'}:</b></font>&nbsp; 
          <select name="default_sort" size=1>
            <option value="-">$board_sort{'normal-opt'}
            <option value="latest-asc">$board_sort{'latest-asc-opt'}
            <option value="latest-desc">$board_sort{'latest-desc-opt'}
            <option value="subject-asc">$board_sort{'subj-asc-opt'}
            <option value="subject-desc">$board_sort{'subj-desc-opt'}
            <option value="creator-asc">$board_sort{'creat-asc-opt'}
            <option value="creator-desc">$board_sort{'creat-desc-opt'}
            <option value="replies-asc">$board_sort{'repl-asc-opt'}
            <option value="replies-desc">$board_sort{'repl-desc-opt'}
            <option value="views-asc">$board_sort{'views-asc-opt'}
            <option value="views-desc">$board_sort{'views-desc-opt'}
          </select>
        </td>
      </tr>
</add after>

<search for>
		$yySetLocation = qq~$cgi;action=manageboards~;
		&redirectexit;
	} else {
</search for>

<add before>
		fopen(FILE, ">$boardsdir/$FORM{'id'}.ord");
		print FILE qq~# Default board sort order\n\$default_sort = "$FORM{'default_sort'}";\n1;\n~;
		fclose(FILE);

</add before>

<search for>
		unlink("$boardsdir/$curboard.ctb");
</search for>

<add after>
		unlink("$boardsdir/$curboard.ord");
</add after>

<search for>
	fopen(FILE, ">$boardsdir/$id.txt");
</search for>

<add before>

	fopen(FILE, ">$boardsdir/$id.ord");
	print FILE qq~# Default board sort order\n\$default_sort = "$FORM{'default_sort'}";\n1;\n~;
	fclose(FILE);
</add before>

<edit file>
english.lng
</edit file>

<search for>
$txt{'800'} = "Other";
</search for>

<add after>

$board_sort{'subject-asc'} = "Click to sort by subject (alphabetical order)";
$board_sort{'subject-desc'} = "Click to sort by subject (reverse alphabetical order)";
$board_sort{'creator-asc'} = "Click to sort by topic creator (alphabetical order)";
$board_sort{'creator-desc'} = "Click to sort by topic creator (reverse alphabetical order)";
$board_sort{'replies-asc'} = "Click to sort by number of replies (least to most)";
$board_sort{'replies-desc'} = "Click to sort by number of replies (most to least)";
$board_sort{'views-asc'} = "Click to sort by number of views (least to most)";
$board_sort{'views-desc'} = "Click to sort by number of views (most to least)";
$board_sort{'latest-asc'} = "Click to sort by most recent activity (oldest first)";
$board_sort{'latest-desc'} = "Click to sort by most recent activity (newest first)";
$board_sort{'asc'} = "Up";
$board_sort{'desc'} = "Down";
$board_sort{'unsort1'} = "Un-sort";
$board_sort{'unsort2'} = "Click to remove sorting";

$board_sort{'sticky'} = "Sticky Topics";
$board_sort{'normal'} = "Normal Topics";

$board_sort{'menu-title'} = "Default sort order";
$board_sort{'normal-opt'} = "Normal";
$board_sort{'latest-asc-opt'} = "Last post (oldest first)";
$board_sort{'latest-desc-opt'} = "Last post (newest first)";
$board_sort{'subj-asc-opt'} = "Subject (alphabetical)";
$board_sort{'subj-desc-opt'} = "Subject (reverse alphabetical)";
$board_sort{'creat-asc-opt'} = "Topic creator (alphabetical)";
$board_sort{'creat-desc-opt'} = "Topic creator (reverse alphabetical)";
$board_sort{'repl-asc-opt'} = "Replies (least to most)";
$board_sort{'repl-desc-opt'} = "Replies (most to least)";
$board_sort{'views-asc-opt'} = "Views (least to most)";
$board_sort{'views-desc-opt'} = "Views (most to least)";
</add after>

<search for>
if($MenuType == 1) {
</search for>

<add after>
	$img{'sort-asc'} = qq~<font size="1" class="imgbg">($board_sort{'asc'})</font>~;
	$img{'sort-desc'} = qq~<font size="1" class="imgbg">($board_sort{'desc'})</font>~;
	$img{'remove-sort'} = qq~<font size="1" class="imgbg">$board_sort{'unsort1'}</font>~;
</add after>

<search for>
}
else {
</search for>

<add after>
	$img{'sort-asc'} = qq~<img src="$imagesdir/sortasc.gif" border="0" alt="$board_sort{'asc'}">~;
	$img{'sort-desc'} = qq~<img src="$imagesdir/sortdesc.gif" border="0" alt="$board_sort{'desc'}">~;
	$img{'remove-sort'} = qq~<img src="$imagesdir/unsort.gif" border="0" alt="$board_sort{'unsort1'}">~;
</add after>
